==> legion_0.4.3.orig.tar.gz: legion-0.4.3/db/entities/app.py <==
"""
LEGION (https://gotham-security.com)
Copyright (c) 2023 Gotham Security

    This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
    License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
    version.

    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
    details.

    You should have received a copy of the GNU General Public License along with this program.
    If not, see <http://www.gnu.org/licenses/>.

Author(s): Shane Scott (sscott@gotham-security.com), Dmitriy Dubson (d.dubson@gmail.com)
"""
from sqlalchemy import Column, String, ForeignKey, Integer

from db.database import Base


class appObj(Base):
    __tablename__ = 'appObj'
    name = Column(String)
    id = Column(Integer, primary_key=True)
    product = Column(String)
    version = Column(String)
    extrainfo = Column(String)
    fingerprint = Column(String)
    cpe = Column(String)
    serviceId = Column(String, ForeignKey('serviceObj.id'))

    def __init__(self, name='', product='', version='', extrainfo='', fingerprint='', cpe=''):
        self.name = name
        self.product = product
        self.version = version
        self.extrainfo = extrainfo
        self.fingerprint = fingerprint
        self.cpe = cpe

==> legion_0.5.2.orig.tar.gz: legion-0.5.2/db/entities/app.py <==
"""
LEGION (https://shanewilliamscott.com)
Copyright (c) 2025 Shane William Scott

    This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
    License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
    version.

    This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
    details.

    You should have received a copy of the GNU General Public License along with this program.
    If not, see <http://www.gnu.org/licenses/>.

Author(s): Shane Scott (sscott@shanewilliamscott.com), Dmitriy Dubson (d.dubson@gmail.com)
"""
from sqlalchemy import Column, String, ForeignKey, Integer

from db.database import Base


class appObj(Base):
    __tablename__ = 'appObj'
    name = Column(String)
    id = Column(Integer, primary_key=True)
    product = Column(String)
    version = Column(String)
    extrainfo = Column(String)
    fingerprint = Column(String)
    cpe = Column(String)
    serviceId = Column(String, ForeignKey('serviceObj.id'))

    def __init__(self, name='', product='', version='', extrainfo='', fingerprint='', cpe=''):
        self.name = name
        self.product = product
        self.version = version
        self.extrainfo = extrainfo
        self.fingerprint = fingerprint
        self.cpe = cpe
